/* Test Ad */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the TestAd repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef NSDictionary<NSString *, id> TADJsonDictionary;
@compatibility_alias JsonDictionary TADJsonDictionary;

typedef NSMutableDictionary<NSString *, id> TADMutableJsonDictionary;
@compatibility_alias MutableJsonDictionary TADMutableJsonDictionary;

FOUNDATION_EXPORT const NSTimeInterval TADAdPrefetchTime;

FOUNDATION_EXPORT NSString * const TAD_DOMAIN_KEY;
FOUNDATION_EXPORT NSString * const TAD_TRANSACTION_STATE_KEY;
FOUNDATION_EXPORT NSString * const TAD_TRACKING_URL_TEMPLATE;
FOUNDATION_EXPORT NSString * const TAD_ORIGINAL_ADUNIT_KEY;
FOUNDATION_EXPORT NSString * const TAD_PRECACHE_CONFIGURATION_KEY;

typedef NS_ENUM(NSInteger, TADLocationSourceValues) {
    TADLocationSourceValuesGPS NS_SWIFT_NAME(GPS) = 1,                              //From Location Service
    TADLocationSourceValuesIPAddress NS_SWIFT_NAME(IPAddress) = 2,                  //Unused by SDK
    TADLocationSourceValuesUserRegistration NS_SWIFT_NAME(UserRegistration) = 3     //Supplied by Publisher
};

//MARK: Accessibility
@interface TADAccesibility: NSObject

//Main close button that appears on Interstitials & Clickthrough Browsers
@property (class, readonly) NSString *CloseButtonIdentifier;
@property (class, readonly) NSString *CloseButtonLabel;

//Secondary close button that only appears on the bottom bar of Clickthrough Browsers
@property (class, readonly) NSString *CloseButtonClickThroughBrowserIdentifier;
@property (class, readonly) NSString *CloseButtonClickThroughBrowserLabel;

@property (class, readonly) NSString *WebViewLabel;

@property (class, readonly) NSString *VideoAdView;

@property (class, readonly) NSString *AdView;

@end

//MARK: MRAID
typedef NSString * TADMRAIDState NS_TYPED_ENUM;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateNotEnabled;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateDefault;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateExpanded;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateHidden;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateLoading;
FOUNDATION_EXPORT TADMRAIDState const TADMRAIDStateResized;


//MARK: Tracking Supression Detection Strings
typedef NSString * TADTrackingPattern NS_TYPED_ENUM;
FOUNDATION_EXPORT TADTrackingPattern const TADTrackingPatternRI;
FOUNDATION_EXPORT TADTrackingPattern const TADTrackingPatternRC;
FOUNDATION_EXPORT TADTrackingPattern const TADTrackingPatternRDF;
FOUNDATION_EXPORT TADTrackingPattern const TADTrackingPatternRR;
FOUNDATION_EXPORT TADTrackingPattern const TADTrackingPatternBO;


//MARK: Query String Parameters
typedef NSString * TADParameterKeys NS_TYPED_ENUM;
FOUNDATION_EXPORT TADParameterKeys const TADParameterKeysAPP_STORE_URL;
FOUNDATION_EXPORT TADParameterKeys const TADParameterKeysOPEN_RTB;

//MARK: TADLocationParamKeys
NS_SWIFT_NAME(TADLocationParamKeys)
@interface TADLocationParamKeys: NSObject

@property (class, readonly) NSString *Latitude                          NS_SWIFT_NAME(Latitude);
@property (class, readonly) NSString *Longitude                         NS_SWIFT_NAME(Longitude);
@property (class, readonly) NSString *Country                           NS_SWIFT_NAME(Country);
@property (class, readonly) NSString *City                              NS_SWIFT_NAME(City);
@property (class, readonly) NSString *State                             NS_SWIFT_NAME(State);
@property (class, readonly) NSString *Zip                               NS_SWIFT_NAME(Zip);
@property (class, readonly) NSString *LocationSource                    NS_SWIFT_NAME(LocationSource);

@end


//MARK: JSON Parse Keys
//TODO: Change Name
NS_SWIFT_NAME(TADParseKey)
@interface TADParseKey: NSObject

@property (class, readonly) NSString *ADUNIT                            NS_SWIFT_NAME(ADUNIT);
@property (class, readonly) NSString *HEIGHT                            NS_SWIFT_NAME(HEIGHT);
@property (class, readonly) NSString *WIDTH                             NS_SWIFT_NAME(WIDTH);
@property (class, readonly) NSString *HTML                              NS_SWIFT_NAME(HTML);
@property (class, readonly) NSString *IMAGE                             NS_SWIFT_NAME(IMAGE);
@property (class, readonly) NSString *NETWORK_UID                       NS_SWIFT_NAME(NETWORK_UID);
@property (class, readonly) NSString *REVENUE                           NS_SWIFT_NAME(REVENUE);
@property (class, readonly) NSString *SSM_TYPE                          NS_SWIFT_NAME(SSM_TYPE);

@end


//MARK: TADAutoRefresh
@interface TADAutoRefresh: NSObject

@property (class, readonly) NSTimeInterval AUTO_REFRESH_DELAY_DEFAULT   NS_SWIFT_NAME(AUTO_REFRESH_DELAY_DEFAULT);
@property (class, readonly) NSTimeInterval AUTO_REFRESH_DELAY_MIN       NS_SWIFT_NAME(AUTO_REFRESH_DELAY_MIN);
@property (class, readonly) NSTimeInterval AUTO_REFRESH_DELAY_MAX       NS_SWIFT_NAME(AUTO_REFRESH_DELAY_MAX);

@end


//MARK: Other Time Intervals
@interface TADTimeInterval: NSObject

@property (class, readonly) NSTimeInterval VAST_LOADER_TIMEOUT          NS_SWIFT_NAME(VAST_LOADER_TIMEOUT);
@property (class, readonly) NSTimeInterval AD_CLICKED_ALLOWED_INTERVAL  NS_SWIFT_NAME(AD_CLICKED_ALLOWED_INTERVAL);
@property (class, readonly) NSTimeInterval CONNECTION_TIMEOUT_DEFAULT   NS_SWIFT_NAME(CONNECTION_TIMEOUT_DEFAULT);
@property (class, readonly) NSTimeInterval CLOSE_DELAY_MIN              NS_SWIFT_NAME(CLOSE_DELAY_MIN);
@property (class, readonly) NSTimeInterval CLOSE_DELAY_MAX              NS_SWIFT_NAME(CLOSE_DELAY_MAX);
@property (class, readonly) NSTimeInterval FIRE_AND_FORGET_TIMEOUT      NS_SWIFT_NAME(FIRE_AND_FORGET_TIMEOUT);

@end


@interface TADVideoConstants: NSObject

@property (class, readonly) NSInteger VIDEO_TIMESCALE                   NS_SWIFT_NAME(VIDEO_TIMESCALE);

@end


//MARK: TADGeoLocationConstants
NS_SWIFT_NAME(TADGeoLocationConstants)
@interface TADGeoLocationConstants: NSObject

@property (class, readonly) double DISTANCE_FILTER                      NS_SWIFT_NAME(DISTANCE_FILTER);

@end


//MARK: TADConstants
@interface TADConstants: NSObject

@property (class, readonly) NSArray <NSString *> *supportedVideoMimeTypes           NS_SWIFT_NAME(supportedVideoMimeTypes);
@property (class, readonly) NSArray <NSString *> *urlSchemesForAppStoreAndITunes    NS_SWIFT_NAME(urlSchemesForAppStoreAndITunes);
@property (class, readonly) NSArray <NSString *> *urlSchemesNotSupportedOnSimulator NS_SWIFT_NAME(urlSchemesNotSupportedOnSimulator);
@property (class, readonly) NSArray <NSString *> *urlSchemesNotSupportedOnClickthroughBrowser NS_SWIFT_NAME(urlSchemesNotSupportedOnClickthroughBrowser);
@property (class, readonly) NSNumber *BUTTON_AREA_DEFAULT                           NS_SWIFT_NAME(BUTTON_AREA_DEFAULT);
@property (class, readonly) NSNumber *SKIP_DELAY_DEFAULT                            NS_SWIFT_NAME(SKIP_DELAY_DEFAULT);
@property (class, readonly) NSNumber *buttonConstraintConstant                      NS_SWIFT_NAME(buttonConstraintConstant);

@end


NS_ASSUME_NONNULL_END
