/* Test Ad */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the TestAd repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <UIKit/UIKit.h>
#import "TADConstants.h"
#import "TADVoidBlock.h"

@class TADModalState;
@class TADAdConfiguration;
@class TADInterstitialDisplayProperties;

typedef void (^TADModalStatePopHandler)(TADModalState * _Nullable poppedState);
typedef void (^TADModalStateAppLeavingHandler)(TADModalState * _Nullable leavingState);

@interface TADModalState: NSObject

@property (nonatomic, strong, nullable, readonly) TADAdConfiguration *adConfiguration;
@property (nonatomic, strong, nullable, readonly) TADInterstitialDisplayProperties *displayProperties;
@property (nonatomic, strong, nullable, readonly) UIView *view;

@property (nonatomic, copy, nonnull) TADMRAIDState mraidState;

@property (nonatomic, copy, nullable, readonly) TADModalStatePopHandler onStatePopFinished;
@property (nonatomic, copy, nullable, readonly) TADModalStateAppLeavingHandler onStateHasLeftApp;

// Used to transfer delegate function to another object, rather then current delegate for next states pushed on top
// ref: MOBILE-5849
@property (nonatomic, copy, nullable, readonly) TADModalStatePopHandler nextOnStatePopFinished;
@property (nonatomic, copy, nullable, readonly) TADModalStateAppLeavingHandler nextOnStateHasLeftApp;

@property (nonatomic, strong, nullable) TADVoidBlock onModalPushedBlock;

@property (nonatomic, assign, readonly, getter=isRotationEnabled) BOOL rotationEnabled;

- (nonnull instancetype)init NS_UNAVAILABLE;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TADAdConfiguration *)adConfiguration
                         displayProperties:(nullable TADInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TADModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)onStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TADAdConfiguration *)adConfiguration
                         displayProperties:(nullable TADInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TADModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable TADModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)nextOnStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TADAdConfiguration *)adConfiguration
                         displayProperties:(nullable TADInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TADModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)onStateHasLeftApp
                        onModalPushedBlock:(nullable TADVoidBlock)onModalPushedBlock;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TADAdConfiguration *)adConfiguration
                         displayProperties:(nullable TADInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TADModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable TADModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable TADModalStateAppLeavingHandler)nextOnStateHasLeftApp
                        onModalPushedBlock:(nullable TADVoidBlock)onModalPushedBlock;

@end
